mse6

package module
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2020 License: Apache-2.0 Imports: 9 Imported by: 0

README

mse6 is a http server implementing mock responses for testing of edge cases, such as slow writes.

Github Workflows Github Issues Github Activity
Codeclimate Maintainability Codeclimate Test Coverage Go Version License

Features

  • Configurable HTTP/1.1 port
  • Configurable wait time for slow responses

Routes

/mse6/die

kills the server process without sending a response

/mse6/get

standard json response with status code 200

/mse6/post

standard json response with status code 200

/mse6/slowheader

sends headers but only after waiting for 3 seconds. Configure with -wait on cli

/mse6/slowbody

sends body after initial lag, then sends some more body without chunking. Configure with -wait on cli

/mse6/badcontentlength

sends invalid content length header, too large for response

/mse6/send?code=nnn

sends arbitrary response code between 100 and 999

/mse6/gzip

sends a gzipped response with proper content encoding

/mse6/badgzip

sends a response gzip content encoding header and garbled binary

Up and running

Osx

brew tap simonmittag/cli &&
brew install mse6 &&
mse6

Golang

go get github.com/simonmittag/mse6 && 
go install github.com/simonmittag/mse6/cmd/mse6 && 
mse6

Usage

λ mse6 -help
Usage of mse6:
  -port int
        the http port (default 8080)
  -test
        server self test
  -wait int
        wait time for server to respond in seconds (default 3)

Contributions

The mse6 team welcomes all contributors. Everyone interacting with the project's codebase, issue trackers, chat rooms and mailing lists is expected to follow the code of conduct

Documentation

Index

Constants

This section is empty.

Variables

var Version = "v0.1.4"

Functions

func Bootstrap

func Bootstrap(port int, waitSeconds float64)

Types

This section is empty.

Directories

Path Synopsis
cmd
mse6 command

Jump to