mse6

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2020 License: Apache-2.0 Imports: 7 Imported by: 0

README

mse6 is a http server implementing mock responses for testing of edge cases, such as slow writes.

Github Workflows Github Issues Github Activity
Codeclimate Maintainability Codeclimate Test Coverage Go Version License

Features

  • Configurable HTTP/1.1 port
  • Configurable wait time for slow responses

Routes

/mse6/get
/mse6/post
/mse6/slowheader
/mse6/slowbody
/mse6/gzip

Up and running

go get github.com/simonmittag/mse6 && go install github.com/simonmittag/mse6/cmd/mse6 && mse6

Usage

λ mse6 -help
Usage of mse6:
  -port int
        the http port (default 8080)
  -wait int
        wait time for server to respond in seconds (default 3)

Contributions

The mse6 team welcomes all contributors. Everyone interacting with the project's codebase, issue trackers, chat rooms and mailing lists is expected to follow the code of conduct

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bootstrap

func Bootstrap(port int, waitSeconds float64)

Types

This section is empty.

Directories

Path Synopsis
cmd
mse6 command

Jump to